require 'json'

class StigParser

  attr_reader :product, :version, :levels, :variants

  Entry = Struct.new(:title, :control_name , :description, :chapter, :automated)

  def initialize(product, version, levels, variants, post_processor)
    @product = product
    @version = version
    @levels = levels
    @variants = variants
    @stig_file = "generate/definitions/stig/#{@product}/#{@version}/TOC.json"
    @content = JSON.parse(File.read(@stig_file))
    @post_processor = post_processor
  end

  def handle_to_long_control_names(control_name)
    case control_name
    when 'enforce_discretionary_access_control_dac_policy_allowing_users_to_specify_and_control_sharing_by_named_individuals_groups_of_individuals_or_by_both_limiting_propagation_of_access_rights_and_including_or_excluding_access_to_the_granularity_of_a_single_user'
      'enforce_discretionary_access_control_dac_policy'
    when ''
    else
      control_name
    end
  end

  def parse()
    entries = []
    @content['stig']['findings'].each do | finding|
      title = finding[1]['title']
      control_name = title
        .gsub(/\"|\'|\(|\)|\;|\:|\,|=|\[|\]/,'')
        .gsub(/\s|\.|\-|\%|\$|\\|\//,'_')
        .gsub('*','')
        .gsub('+','_plus_')
        .gsub('&','_and_')
        .gsub(/_+/,'_')
        .gsub(/__/,'_')
        .gsub(/^_/,'')
        .gsub(/_$/,'')
        .downcase
        .gsub(/__/,'_')
        .gsub(/^the_dbms_must_/,'')
        .gsub(/^dbms_must_/,'')
        .gsub(/^the_/,'')
        .gsub(/^system_must_/,'')
        .gsub(/^a_/,'')
      control_name = handle_to_long_control_names(control_name)
      automated = true
      description = finding[1]['checktext'] + "\n\n" + finding[1]['fixtext']
      chapter = finding[1]['id']
      entry = Entry.new(title, control_name, description, chapter, automated )
      entries << entry
    end
    entries
  end
end